#
# spec file for package python-jupyter_nbconvert
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jupyter_nbconvert
Version:        5.4.1
Release:        lp151.1.5
# May not be necessary in next version
%define doc_ver 5.4
Summary:        Conversion of Jupyter Notebooks
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/nbconvert
Source0:        https://files.pythonhosted.org/packages/source/n/nbconvert/nbconvert-%{version}.tar.gz
Source1:        https://media.readthedocs.org/pdf/nbconvert/%{doc_ver}/nbconvert.pdf
Source2:        https://media.readthedocs.org/htmlzip/nbconvert/%{doc_ver}/nbconvert.zip
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
# Test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module bleach}
BuildRequires:  %{python_module defusedxml}
BuildRequires:  %{python_module entrypoints >= 0.2.2}
BuildRequires:  %{python_module jupyter_client >= 4.2}
BuildRequires:  %{python_module jupyter_core}
BuildRequires:  %{python_module jupyter_ipykernel}
BuildRequires:  %{python_module jupyter_nbformat >= 4.4}
BuildRequires:  %{python_module mistune >= 0.7.4}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pandocfilters >= 1.4.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testpath}
BuildRequires:  %{python_module tornado >= 4.0}
BuildRequires:  %{python_module traitlets >= 4.2}
# Python 2 test requirements
Requires:       python-Jinja2
Requires:       python-Pygments
Requires:       python-bleach
Requires:       python-defusedxml
Requires:       python-entrypoints >= 0.2.2
Requires:       python-jupyter_core
Requires:       python-jupyter_nbformat >= 4.4
Requires:       python-mistune >= 0.7.4
Requires:       python-pandocfilters >= 1.4.1
Requires:       python-testpath
Requires:       python-traitlets >= 4.2
Recommends:     pandoc
Recommends:     python-jupyter_client >= 4.2
Recommends:     python-tornado >= 4.0
Suggests:       %{name}-latex
BuildArch:      noarch
%python_subpackages

%description
The jupyter nbconvert package converts notebooks to various other formats
via Jinja templates.

%package        latex
Summary:        LaTeX support for nbconvert
Group:          Development/Languages/Python
Requires:       texlive-bibtex
Requires:       texlive-makeindex
Requires:       tex(adjustbox.sty)
Requires:       tex(eurosym.sty)
Requires:       tex(ulem.sty)

%description    latex
The jupyter nbconvert package converts notebooks to various other formats
via Jinja templates.

This package pulls in the LaTeX dependencies for nbconvert.

%package     -n python-jupyter_nbconvert-doc
Summary:        Documentation for python-jupyter_nbconvert
Group:          Documentation/Other
Provides:       %{python_module jupyter_nbconvert-doc = %{version}}

%description -n python-jupyter_nbconvert-doc
Documentation and help files for python-jupyter_nbconvert.

%prep
%setup -q -n nbconvert-%{version}
cp %{SOURCE1} .
unzip %{SOURCE2} -d docs
mv docs/nbconvert-* docs/html
rm docs/html/.buildinfo

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%{python_expand chmod a+x %{buildroot}%{$python_sitelib}/nbconvert/nbconvertapp.py
chmod a+x %{buildroot}%{$python_sitelib}/nbconvert/filters/filter_links.py
sed -i "s|^#!%{_bindir}/env python$|#!%{__$python}|" %{buildroot}%{$python_sitelib}/nbconvert/nbconvertapp.py
sed -i "s|^#!%{_bindir}/env python3$|#!%{__$python}|" %{buildroot}%{$python_sitelib}/nbconvert/filters/filter_links.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/nbconvert/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/nbconvert/
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/nbconvert/filters/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/nbconvert/filters/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
pushd docs
export LANG=en_US.UTF-8
# test_run_notebooks disabled until IPython 7 incompatibility in tests fixed.
# See https://github.com/jupyter/nbconvert/issues/898
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -m ipykernel.kernelspec --user
%pytest --pyargs -k 'not (test_svg_handling or test_run_notebooks)' nbconvert
}
popd

%files %{python_files}
%license LICENSE
%doc README.md
%python3_only %{_bindir}/jupyter-nbconvert
%{python_sitelib}/*

%files %{python_files latex}
%license LICENSE

%files -n python-jupyter_nbconvert-doc
%license LICENSE
%doc nbconvert.pdf
%doc docs/html

%changelog
* Wed Mar 13 2019 Matej Cepl <mcepl@suse.com>
- Update to 5.4.1:
  - New Features
  - Expose pygments styles
  - Tornado 6.0 support -- Convert proxy handler from callback
    to coroutine
  - Add option to overwrite the highlight_code filter
  - Fixing Problems
  - Mathjax.tpl fix for rendering Latex in html
  - Backwards compatbility for empty kernel names
  - Testing, Docs, and Builds
  - DOC: Add missing language specification to code-block
- Switch to %%pytest
* Tue Nov 20 2018 Todd R <toddrme2178@gmail.com>
- Disable test due to use of old IPython reference files.
  See https://github.com/jupyter/nbconvert/issues/898
* Mon Sep 10 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrasing for summary.
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 5.4.0
  + New Features
  * No input flag (``--no-input``)
  * Add alias ``--to ipynb`` for notebook exporter
  * Add ``export_from_notebook``
  * If set, use ``nb.metadata.authors`` for LaTeX author line
  * Populate language_info metadata when executing
  * Support for ``\mathscr``
  * Allow the execute preprocessor to make use of an existing kernel
  * Refactor ExecutePreprocessor
  * Update widgets CDN for ipywidgets 7 w/fallback
  * Add support for adding custom exporters to the "Download as" menu.
  * Enable ANSI underline and inverse
  * Update notebook css to 5.4.0
  * Change default for slides to direct to the reveal cdn rather than locally
  * Use "title" instead of "name" for metadata to match the notebook format
  * Img filename metadata
  * Added MathJax compatibility definitions
  * Per cell exception
  * Simple API for in-memory templates
  * Set BIBINPUTS and BSTINPUTS environment variables when making PDF
  * If ``nb.metadata.title`` is set, default to that for notebook
  + Deprecations
  * Drop support for python 3.3
  + Fixing Problems
  * Fix api break
  * Don't remove empty cells by default
  * Handle attached images in html converter
  * No need to check for the channels already running
  * Update ``font-awesome`` version for slides
  * Properly treat JSON data
  * Skip executing empty code cells
  * Ppdate log.warn (deprecated) to log.warning
  * Cleanup notebook.tex during PDF generation
  * Windows unicode error fixed, nosetest added to setup.py
  * Better content hiding; template & testing improvements
  * Fix Jinja syntax in custom template example.
  * Fix for an issue with empty math block
  * Add parser for Multiline math for LaTeX blocks
  * Use defusedxml to parse potentially untrusted XML
  * Fixes for traitlets 4.1 deprecation warnings
  + Testing, Docs, and Builds
  * A couple of typos
  * Add python_requires metadata.
  * Document ``--inplace`` command line flag.
  * Fix minor typo in ``usage.rst``
  * Add note about local ``reveal_url_prefix``
  * Move ``onlyif_cmds_exist`` decorator to test-specific utils
  * Include LICENSE file in wheels
  * Added Ubuntu Linux Instructions
  * Check for too recent of pandoc version
  * Removing more nose remnants via dependencies.
  * Remove offline statement and add some clarifications in slides docs
  * Linkify PR number
  * Added shebang for python
  * Upgrade mistune dependency
  * add feature to improve docs by having links to prs
  * Update notebook CSS from version 4.3.0 to 5.1.0
  * Explicitly exclude or include all files in Manifest.
- Use documentation provided by upstream.
* Thu Jul 26 2018 mcepl@suse.com
- Clean up SPEC file.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 5.3.1
  * MANIFEST.in updated to include ``LICENSE`` and ``scripts/`` when creating sdist. #666
- Update to 5.3
  + Major features
  * Tag Based Element Filtering
  + new features
  * configurable ``browser`` in ServePostProcessor #618
  * ``--clear-output`` command line flag to clear output in-place #619
  * remove elements based on tags with ``TagRemovePreprocessor``. #640, #643
  * CellExecutionError can now be imported from ``nbconvert.preprocessors`` #656
  * slides now can enable scrolling and custom transitions #600
  + Documentation
  * Release instructions for nbviewer-deploy
  * improved instructions for handling errors using the ``ExecutePreprocessor`` #656
  + Testing
  * better height/width metadata testing for images in rst & html #601 #602
  * normalise base64 output data to avoid false positives #650
  * normalise ipython traceback messages to handle old and new style #631
  + Bugfixes
  * mathjax obeys ``\\(\\)`` & ``\\[\\]`` (both nbconvert & pandoc) #609 #617
  * specify default templates using extensions #639
  * fix pandoc version number #638
  * require recent mistune version #630
  * catch errors from IPython ``execute_reply`` and ``error`` messages #642
  + Other
  * nose completely removed & dependency dropped #595 #660
  * mathjax processing in mistune now only uses inline grammar #611
  * removeRegex now enabled by default on all TemplateExporters, does not remove cells with outputs #616
  * validate notebook after applying each preprocessor (allowing additional attributes) #645
  * changed COPYING.md to LICENSE for more standard licensing that GitHub knows how to read #654
- Update to 5.2
  + Major features
  * Global Content Filtering
  * Execute notebooks from a function
  * Remove cells based on regex pattern
  * Script exporter entrypoints for nonpython scripts
  + New features
  * configurable ExecutePreprocessor.startup_timeout configurable #583
  * RemoveCell preprocessor based on cell content (defaults to empty cell) #575
  * function for executing notebooks: `executenb` #573
  * global filtering to remove inputs, outputs, markdown cells (&c.), this works on all templates #554
  * script exporter entrypoint #531
  * configurable anchor link text (previously ¶) `HTMLExporter.anchor_link_text` #522
  * configurable values for slides exporter #542 #558
  + Bugfixes
  * we now respect width and height metadata on jpeg and png mimetype outputs #588
  * now we respect the `resolve_references` filter in `report.tplx` #577
  * output metadata now is removed by ClearOutputPreprocessor #569
  * display id respected in execute preproessor #563
  * dynamic defaults for optional jupyter_client import #559
  * don't self-close non-void HTML tags #548
  * upgrade jupyter_client dependency to 4.2 #539
  * LaTeX output through md→LaTeX conversion shouldn't be touched #535
  * now we escape `<` inside math formulas when converting to html #514
  + Other
  * improved releases (how-to documentation, version-number generation and checking) #593
  * doc improvements  #593 #580 #565 #554
  * language information from cell magics (for highlighting) is now included in more formats #586
  * mathjax upgrades and cdn fixes #584 #567
  * better CI #571 #540
  * better traceback behaviour when execution errs #521
  * deprecated nose test features removed #519
* Wed Sep 13 2017 jmatejek@suse.com
- switch texlive Recommends to Suggests - let's not pull the whole
  texlive for this particular package
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 5.1.1
  * fix version numbering because of incomplete previous version number
- Update to 5.1
  * improved CSS (specifically tables, in line with notebook) #498
  * improve in-memory templates handling #491
  * test improvements #516 #509 #505
  * new configuration option: IOPub timeout #513
  * doc improvements #489 #500 #493 #506
  * newly customizable: output prompt #500
  * more python2/3 compatibile unicode handling #502
- Update to 5.0
  * Use :command:`xelatex` by default for latex export, improving unicode and font support.
  * Use entrypoints internally to access Exporters, allowing for packages to declare custom exporters more easily.
  * New ASCIIDoc Exporter.
  * New preprocessor for sanitised html output.
  * New general ``convert_pandoc`` filter to reduce the need to hard-code lists of filters in templates.
  * Use pytest, nose dependency to be removed.
  * Refactored Exporter code to avoid ambiguity and cyclic dependencies.
  * Update to traitlets 4.2 API.
  * Fixes for Unicode errors when showing execution errors on Python 2.
  * Default math font matches default Palatino body text font.
  * General documentation improvements. For example, testing, installation, custom exporters.
  * Improved link handling for LaTeX output
  * Refactored the automatic id generation.
  * New kernel_manager_class configuration option for allowing systems to be set up to resolve kernels in different ways.
  * Kernel errors now will be logged for debugging purposes when executing notebooks.
- Update to 4.3
  * added live widget rendering for html output, nbviewer by extension
- Update to 4.2
  * :ref:`Custom Exporters <external_exporters>` can be provided by external packages,
  and registered with nbconvert via setuptools entrypoints.
  * allow nbconvert reading from stdin with ``--stdin`` option (write into
  ``notebook`` basename)
  * Various ANSI-escape fixes and improvements
  * Various LaTeX/PDF export fixes
  * Various fixes and improvements for executing notebooks with ``--execute``.
- Create doc subpackage
* Mon Mar  7 2016 toddrme2178@gmail.com
- Update to 4.1.0
  * setuptools fixes for entrypoints on Windows
  * various fixes for exporters, including slides, latex, and PDF
  * fixes for exceptions met during execution
  * include markdown outputs in markdown/html exports
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Thu Aug 13 2015 toddrme2178@gmail.com
- Initial version
